[−][src]Enum unicode_types::grantha::Grantha
An enum to represent all characters in the Grantha block.
Variants
SignCombiningAnusvaraAbove\u{11300}: '𑌀'
SignCandrabindu\u{11301}: '𑌁'
SignAnusvara\u{11302}: '𑌂'
SignVisarga\u{11303}: '𑌃'
LetterA\u{11305}: '𑌅'
LetterAa\u{11306}: '𑌆'
LetterI\u{11307}: '𑌇'
LetterIi\u{11308}: '𑌈'
LetterU\u{11309}: '𑌉'
LetterUu\u{1130a}: '𑌊'
LetterVocalicR\u{1130b}: '𑌋'
LetterVocalicL\u{1130c}: '𑌌'
LetterEe\u{1130f}: '𑌏'
LetterAi\u{11310}: '𑌐'
LetterOo\u{11313}: '𑌓'
LetterAu\u{11314}: '𑌔'
LetterKa\u{11315}: '𑌕'
LetterKha\u{11316}: '𑌖'
LetterGa\u{11317}: '𑌗'
LetterGha\u{11318}: '𑌘'
LetterNga\u{11319}: '𑌙'
LetterCa\u{1131a}: '𑌚'
LetterCha\u{1131b}: '𑌛'
LetterJa\u{1131c}: '𑌜'
LetterJha\u{1131d}: '𑌝'
LetterNya\u{1131e}: '𑌞'
LetterTta\u{1131f}: '𑌟'
LetterTtha\u{11320}: '𑌠'
LetterDda\u{11321}: '𑌡'
LetterDdha\u{11322}: '𑌢'
LetterNna\u{11323}: '𑌣'
LetterTa\u{11324}: '𑌤'
LetterTha\u{11325}: '𑌥'
LetterDa\u{11326}: '𑌦'
LetterDha\u{11327}: '𑌧'
LetterNa\u{11328}: '𑌨'
LetterPa\u{1132a}: '𑌪'
LetterPha\u{1132b}: '𑌫'
LetterBa\u{1132c}: '𑌬'
LetterBha\u{1132d}: '𑌭'
LetterMa\u{1132e}: '𑌮'
LetterYa\u{1132f}: '𑌯'
LetterRa\u{11330}: '𑌰'
LetterLa\u{11332}: '𑌲'
LetterLla\u{11333}: '𑌳'
LetterVa\u{11335}: '𑌵'
LetterSha\u{11336}: '𑌶'
LetterSsa\u{11337}: '𑌷'
LetterSa\u{11338}: '𑌸'
LetterHa\u{11339}: '𑌹'
CombiningBinduBelow\u{1133b}: '𑌻'
SignNukta\u{1133c}: '𑌼'
SignAvagraha\u{1133d}: '𑌽'
VowelSignAa\u{1133e}: '𑌾'
VowelSignI\u{1133f}: '𑌿'
VowelSignIi\u{11340}: '𑍀'
VowelSignU\u{11341}: '𑍁'
VowelSignUu\u{11342}: '𑍂'
VowelSignVocalicR\u{11343}: '𑍃'
VowelSignVocalicRr\u{11344}: '𑍄'
VowelSignEe\u{11347}: '𑍇'
VowelSignAi\u{11348}: '𑍈'
VowelSignOo\u{1134b}: '𑍋'
VowelSignAu\u{1134c}: '𑍌'
SignVirama\u{1134d}: '𑍍'
Om\u{11350}: '𑍐'
AuLengthMark\u{11357}: '𑍗'
SignPluta\u{1135d}: '𑍝'
LetterVedicAnusvara\u{1135e}: '𑍞'
LetterVedicDoubleAnusvara\u{1135f}: '𑍟'
LetterVocalicRr\u{11360}: '𑍠'
LetterVocalicLl\u{11361}: '𑍡'
VowelSignVocalicL\u{11362}: '𑍢'
VowelSignVocalicLl\u{11363}: '𑍣'
CombiningDigitZero\u{11366}: '𑍦'
CombiningDigitOne\u{11367}: '𑍧'
CombiningDigitTwo\u{11368}: '𑍨'
CombiningDigitThree\u{11369}: '𑍩'
CombiningDigitFour\u{1136a}: '𑍪'
CombiningDigitFive\u{1136b}: '𑍫'
CombiningDigitSix\u{1136c}: '𑍬'
CombiningLetterA\u{11370}: '𑍰'
CombiningLetterKa\u{11371}: '𑍱'
CombiningLetterNa\u{11372}: '𑍲'
CombiningLetterVi\u{11373}: '𑍳'
CombiningLetterPa\u{11374}: '𑍴'
Methods
impl Grantha[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case